options mprint;
**********************************************************************************;
* compare_datasets.sas                                                           *;
*                                                                                *;
* Sample driver program to compare SAS data sets                                 *;
**********************************************************************************;

**********************************************************************************;
* Location of this folder structure                                              *;
**********************************************************************************;
%let DatasetXMLRoot=/datasetxml;

**********************************************************************************;
* Set Root paths for input and output                                            *;
**********************************************************************************;
%let studyRootPath=/datasetxml;
%let studyOutputPath=/datasetxml;

**********************************************************************************;
* Make the macros available                                                      *;
**********************************************************************************;
options mautosource sasautos=("&DatasetXMLRoot/macros", sasautos);

**********************************************************************************;
* Initialize results dataset and make messages available                         *;
**********************************************************************************;
libname messages "&DatasetXMLRoot/messages";
%let _cstMessages=messages.messages;

libname results "&studyOutputPath/results";
%let _cstResultsDS=results.compare_results;

data &_cstResultsDS;
  %cstutil_resultsdsattr;
  call missing(of _all_);
  stop;
run;  


**********************************************************************************;
* Compare SDTM SAS Data sets                                                     *;
**********************************************************************************;
libname database "&studyRootPath/sasdata/original/sdtm";
libname datacomp "&studyRootPath/sasdata/imported/sdtm";

%cstutilcomparedatasets(
  _cstLibBase=database,   
  _cstLibComp=datacomp, 
  _cstCompareLevel=16, 
  _cstCompOptions=%str(criterion=0.00000000000001),
  _cstCompDetail=Y
  ); 
  
**********************************************************************************;
* Compare ADaM SAS Data sets                                                     *;
**********************************************************************************;
libname database "&studyRootPath/sasdata/original/adam";
libname datacomp "&studyRootPath/sasdata/imported/adam";

%cstutilcomparedatasets(
  _cstLibBase=database,   
  _cstLibComp=datacomp, 
  _cstCompareLevel=16, 
  _cstCompOptions=%str(criterion=0.00000000000001),
  _cstCompDetail=Y
  ); 
  
*******************************************************************************;
* Check results dataset for errors and warnings, and print in SAS log file.    ;
*******************************************************************************;
data _null_;
  format _character_;
  set &_cstResultsDS;
  if (resultflag ne 0) or (upcase(resultseverity) in ('WARNING' 'ERROR')) then do;
     resultseverity=upcase(resultseverity);
     putlog resultseverity +(-1) ": [CSTLOG%str(MESSAGE)] " message @;
     if not missing(resultdetails) then putlog ": "  resultdetails;
                                   else putlog;
  end;
run;
 